@@ -25,8 +25,13 @@ def telogrep_main(argv=None):
             "-o", "--omit-telomereless", action="store_true",
             help="Don't output for contigs with neither 5' or 3' telomeres"
     )
+    ap.add_argument(
+            "-T", "--tsv", action="store_true",
+            help="Output as a TSV for easy reading into other tools."
+    )
     args = ap.parse_args(argv)
 
+    # These are taken from https://dx.doi.org/10.1093/gbe/evt019
     tel_forward = "C{2,4}T{1,2}A{1,3}"
     tel_reverse = "T{1,3}A{1,2}G{2,4}"
 
@@ -35,6 +40,9 @@ def telogrep_main(argv=None):
     nrev = 0
     nfwd = 0
 
+    if args.tsv:
+        print("contig", "contig_len", "n_bp_fwd", "teloseq_fwd", "n_bp_rev", "teloseq_rev", sep="\t")
+
     for record in SeqIO.parse(args.fasta, "fasta"):
         ctgid = str(record.description).split(" ")[0]
         sequence = str(record.seq).upper()
@@ -48,25 +56,35 @@ def telogrep_main(argv=None):
         revbp = sum(revlens)
 
         fwdstr = ""
+        mcfwd = ""
         if fwdbp > min_bp:
             mcfwd = Counter(fwds).most_common(1)[0][0]
             fwdstr = "{}bp of ({})".format(fwdbp, mcfwd)
             nfwd += 1
+        else:
+            fwdbp = 0
 
         revstr = ""
+        mcrev = ""
         if revbp > min_bp:
             mcrev = Counter(revs).most_common(1)[0][0]
             revstr = "{}bp of ({})".format(revbp, mcrev)
             nrev += 1
+        else:
+            revbp = 0
         
         if args.omit_telomereless and fwdstr == "" and revstr == "":
             continue
         
-        print('{:<20} ({:>9}bp) {:>20} ------- {:<20}'.format(ctgid, len(sequence), fwdstr, revstr))
+        if args.tsv:
+            print(ctgid, len(sequence), fwdbp, mcfwd, revbp, mcrev, sep="\t")
+        else:
+            print('{:<20} ({:>9}bp) {:>20} ------- {:<20}'.format(ctgid, len(sequence), fwdstr, revstr))
     
-    print()
-    print('{:<20}               {:>20} ------- {:<20}'.format("TOTAL:", "{} 5' Telos".format(nfwd),
-                                                           "{} 3' Telos".format(nrev)))
+    if not args.tsv:
+        print()
+        print('{:<20}               {:>20} ------- {:<20}'.format("TOTAL:", "{} 5' Telos".format(nfwd),
+                                                                            "{} 3' Telos".format(nrev)))
 
 if __name__ == "__main__":
     telogrep_main()
